@@ -9,6 +9,7 @@ from .handlers import (
     StartHandler,
     TextHandler,
     UpdateHandler,
+    MessageOrQueryHandler,
 )
 from .keyboards import InlineButtons, InlineKeyboard
 from .loader import app
@@ -29,4 +30,5 @@ __all__ = [
     "CommandHandler",
     "StartHandler",
     "StartGroupHandler",
+    "MessageOrQueryHandler",
 ]
