@@ -1,11 +1,10 @@
 from .command import CommandHandler
-from .inline_menu import InlineMenuHandler
 from .message import MessageHandler
 from .query import QueryHandler
 from .start import StartGroupHandler, StartHandler
 from .text import TextHandler
 from .update import UpdateHandler
-
+from .message_or_query import MessageOrQueryHandler
 __all__ = [
     "UpdateHandler",
     "MessageHandler",
@@ -13,6 +12,6 @@ __all__ = [
     "TextHandler",
     "CommandHandler",
     "StartHandler",
-    "InlineMenuHandler",
     "StartGroupHandler",
+    "MessageOrQueryHandler",
 ]
