@@ -15,7 +15,7 @@ class Query(TelegramObject):
     def data(self) -> str:
         return self.get_validated_field("data", self.raw.data)
 
-    async def answer(self, text: str, *, show_alert: bool = False) -> bool:
+    async def answer(self, text: str = "", *, show_alert: bool = False) -> bool:
         return await self.raw.answer(text, show_alert)
 
     @property
